Utilities for AWS Lambda functions
==================================

[![Build Status](https://travis-ci.org/humilis/humilis-lambdautils.svg?branch=master)](https://travis-ci.org/humilis/humilis-lambdautils)
[![PyPI](https://img.shields.io/pypi/v/lambdautils.svg?style=flat)](https://pypi.python.org/pypi/lambdautils)

Basic utilities for Lambda event processors that are deployed using 
[humilis][humilis] `lambda` references.

[humilis]: https://github.com/humilis/humilis


## Development

Assuming you have [virtualenv][virtualenv] installed:

[virtualenv]: https://virtualenv.readthedocs.org/en/latest/

```
make develop
```


## Testing

To run the local test suite (does not require deployment):

```
make test
```


## Contact

If you have questions, bug reports, suggestions, etc. please create an issue
on the [GitHub project page][projectpage].

[projectpage]: https://github.com/humilis/humilis-lambdautils


## License

This software is licensed under the [MIT license](http://en.wikipedia.org/wiki/MIT_License).

See [License file](https://github.com/humilis/humilis-lambdautils/blob/master/LICENSE.txt).


© 2016 German Gomez-Herrero, [FindHotel](http://findhotel.net) and others.
